#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""PyAsciiArt
    Convert image to character painting.

Usage:
    PyAsciiArt.py <file>... [--contrast C_NUMBER]
                            [--resize WIDTH]
                            [-o OUTPUT_FILE]
                            [-r]
    PyAsciiArt.py (-h | --help)
    PyAsciiArt.py --version

Example:
    PyAsciiArt.py example.png
    PyAsciiArt.py example.png --resize 100 -o result.txt
    PyAsciiArt.py example.png --resize 100 --contrast 0.5 -r

Options:
    --contrast C_NUMBER     Change the image contrast.
    --resize WIDTH          Modify image size, keep proportion by default. The unit is pixel.
    -o OUTPUT_FILE          Output filename.
    -r                      Reverse the result, dark background image may get better result
    -h --help               Show help.
    --version               Show version.

"""
import os
from docopt import docopt
from PIL import Image, ImageEnhance


def resize(image, WIDTH):

    original_width = image.size[0]
    original_height = image.size[1]
    return image.resize((int(WIDTH), int(original_height /
                                         original_width * WIDTH)), Image.NEAREST)


def main(arguments):

    for imageFile in arguments['<file>']:
        im = Image.open(imageFile)
        filename = os.path.basename(imageFile).split('.')[0]
        character = r'$@%#=;-. '

        if arguments['--resize'] is not None:
            im = resize(im, int(arguments['--resize']))

        if arguments['--contrast'] is not None:
            enh = ImageEnhance.Contrast(im)
            im = enh.enhance(1.0 + float(arguments['--contrast']))

        if arguments['-r']:
            character = character[::-1]

        interval = 256 / len(character)
        height = im.size[1]
        width = im.size[0]
        im = im.convert('L')
        if arguments['-o'] is not None:
            f = open(arguments['-o'], 'w')
        else:
            f = open(filename + '_ascii.txt', 'w')
        for row in range(height):
            s = ''
            for column in range(width):
                value = im.getpixel((column, row)) // interval
                s += character[int(value)]
            s += '\n'
            f.writelines(s)
        f.close()


if __name__ == '__main__':
    arguments = docopt(__doc__)
    main(arguments)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-


import os
from PIL import Image, ImageEnhance


def crop(image, WIDTH):

    original_width = image.size[0]
    original_height = image.size[1]
    return image.resize((int(WIDTH), int(original_height /
                                         original_width * WIDTH)), Image.NEAREST)


def convert(fname, resize=None, contrast=None, reverse=False, output=None):
    """
    Use this function to convert image to a character painting

    - fname     Input filename
    - resize    Modify image size, keep proportion by default
                the unit is pixel, default does not crop
    - contrast  The value of changing the image contrast
    - reverse   Reverse the result, dark background image may get better
    - output    Output filename
    """

    im = Image.open(fname)
    filename = os.path.basename(fname).split('.')[0]
    character = r'$@%#=;-. '

    if resize is not None:
        im = crop(im, resize)

    if contrast is not None:
        enh = ImageEnhance.Contrast(im)
        im = enh.enhance(1.0 + float(contrast))

    if reverse:
        character = character[::-1]

    interval = 256 / len(character)
    height = im.size[1]
    width = im.size[0]
    im = im.convert('L')

    if output is not None:
        f = open(output, 'w')
    else:
        f = open(filename + '_ascii.txt', 'w')
    for row in range(height):
        s = ''
        for column in range(width):
            value = im.getpixel((column, row)) // interval
            s += character[int(value)]
        s += '\n'
        f.writelines(s)
    f.close()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup


setup(
    name='PyAsciiArt',
    version='1.3.0',
    description='Convert image to character painting.',
    long_description='More information you can see: https://github.com/emptyxl/PyAsciiArt',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Topic :: Utilities'
    ],
    keywords='python PyAsciiArt character painting',
    author='empty_xl',
    author_email='empty_xl@163.com',
    license='MIT',
    packages=['PyAsciiArt'],
    url='https://github.com/emptyxl/PyAsciiArt',
    install_requires=[
        'Pillow',
        'docopt'
    ],
    entry_points={
        'console_scripts': [
            'PyAsciiArt = PyAsciiArt.PyAsciiArt:main'
        ]
    },
)
